@@ -1,43 +1,7 @@
-###############################################################################################
-
-# Function Description
-#   Rating scale reduction
-#   This package implements a rather sophisticated method published in (Koczkodaj et al., 2017) In
-#   essence, it is a stepwise method fro maximizing the area under the area (AUC) of receiver operating
-#   characteristic (ROC). In this description, data mining terminology will be used:
-#       1.examples (observations in statistics),
-#       2.variables in statistics,
-#       3.class or decision attribute (decision variable may be used statistics).
-#   The implemented algorithm (when reduced to its minimum) comes to using a loop for all attributes
-#   (with the class excluded) to compute AUC. Subsequently, attributes are sorted in the descending
-#   order by AUC. The attribute with the largest AUC is added to a subset of all attributes (evidently, it
-#   cannot be empty since it is supposed to be the minimum subset S of all attributes with the maximum
-#   AUC). We keep adding the next in line (according to AUC) attribute to the subset S checking AUC.
-#   If it decreases, we stop the procedure. The above procedure can be described by the following
-#   algorithm.
-#   Algorithm:
-#       1. compute AUC of all attributes excluding class
-#       2. sort attributes by their AUC in the ascending order
-#       3. select the attribute with the largest AUC to subset S
-#       4. select the next attribute A with the largest AUC to subset S
-#       5. if the AUC of the subset S is larger that AUC of the former AUC then go to 3
-#   There are a lot of checking (e.g., if the dataset is not empty or full of replications) involved.
-
-# Parameters
-#   attribute: a matrix or data.frame containing attributes
-#       D: the decision vector
-#       plotRSR: If TRUE the ROC curve is ploted
-#   method: the Stop reduction criteria: First Max of AUC or Global Max of AUC
-
-# Return result
-#   rsr.auc: total AUC of atrtibutes
-#   rsr.label: attribute labels
-#   summary: a summary table
-###############################################################################################
-
-rsr <- function(attribute, D, plotRSR = FALSE, method = c("Stop1Max", "StopGlobalMax")) {
+rsr <-
+function(attribute, D, plotRSR = FALSE, method = c("Stop1Max", "StopGlobalMax")) {
     method <- match.arg(method)
-	if (length(names(attribute)) == 0) {
+if (length(names(attribute)) == 0) {
         outlist <- list(message("names(attribute)==NULL Create attribute LABELS (e.g. using colnames)"))
     }
     
@@ -118,8 +82,8 @@ rsr <- function(attribute, D, plotRSR = FALSE, method = c("Stop1Max", "StopGloba
 
             } 
             else { if (length(auc.reduct) == 1) {  
-						outlist <- list(rsr.auc = auc.reduct, rsr.label = names(s1)[1], summary = tab)}
-							else {
+outlist <- list(rsr.auc = auc.reduct, rsr.label = names(s1)[1], summary = tab)}
+else {
                 outlist <- list(rsr.auc = auc.reduct, rsr.label = names(s1[1, 1:length(auc.reduct)]), 
                   summary = tab)}}
     }
